@@ -216,7 +216,7 @@ class KlineDetail(AutoSaveDetail):
               ,low	    float	-- 本阶段最低价
               ,high	    float	-- 本阶段最高价
               ,vol	    float	-- 以报价币种计量的交易量
-              ,primary key (id)           
+              ,primary key (symbol,id)           
               )
             """.format(self.table_name))
 
