@@ -41,10 +41,10 @@ class TradeUpdate:
         self.kline_1year.create()
 
     @staticmethod
-    def replace_key(data_dicts: list):
+    def replace_key(data_dicts: list, symbol=None):
         res = []
         for _data_dict in data_dicts:
-            data_dict = {}
+            data_dict = {"symbol": symbol}
             for key in _data_dict.keys():
                 data_dict[key.replace('-', '_')] = _data_dict[key]
             res.append(data_dict)
@@ -58,29 +58,29 @@ class TradeUpdate:
         datas = history.dict_data['data']
         result = []
         [result.extend(data['data']) for data in datas]
-        self.tradeDB.insert_list(self.replace_key(result))
+        self.tradeDB.insert_list(self.replace_key(result, symbol=symbol))
 
     def insert_kline(self, symbol):
-        self.kline_1min.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='1min', size=2000).dict_data['data']))
-        self.kline_5min.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='5min', size=2000).dict_data['data']))
-        self.kline_15min.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='15min', size=2000).dict_data['data']))
-        self.kline_30min.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='30min', size=2000).dict_data['data']))
-        self.kline_60min.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='60min', size=2000).dict_data['data']))
-        self.kline_4hour.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='4hour', size=2000).dict_data['data']))
-        self.kline_1day.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='1day', size=2000).dict_data['data']))
-        self.kline_1mon.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='1mon', size=2000).dict_data['data']))
-        self.kline_1week.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='1week', size=2000).dict_data['data']))
-        self.kline_1year.insert_list(self.replace_key(
-            self.market.get_candlestick(symbol=symbol, period='1year', size=2000).dict_data['data']))
+        self.kline_1min.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='1min', size=2000).dict_data['data'], symbol))
+        self.kline_5min.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='5min', size=2000).dict_data['data'], symbol))
+        self.kline_15min.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='15min', size=2000).dict_data['data'], symbol))
+        self.kline_30min.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='30min', size=2000).dict_data['data'], symbol))
+        self.kline_60min.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='60min', size=2000).dict_data['data'], symbol))
+        self.kline_4hour.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='4hour', size=2000).dict_data['data'], symbol))
+        self.kline_1day.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='1day', size=2000).dict_data['data'], symbol))
+        self.kline_1mon.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='1mon', size=2000).dict_data['data'], symbol))
+        self.kline_1week.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='1week', size=2000).dict_data['data'], symbol))
+        self.kline_1year.insert_list(self.replace_key(self.market.get_candlestick(
+            symbol=symbol, period='1year', size=2000).dict_data['data'], symbol))
 
     def auto_save(self):
         self.tradeDB.auto_save()
@@ -138,14 +138,14 @@ class TradeUpdate:
             self.insert_symbol()
             if t % 10 == 0:
                 self._save()
-                pass
+
             if t % 100 == 0:
                 self.insert_data(trade=True, kline=True)
                 self.auto_save()
             else:
                 self.insert_data(trade=True, kline=False)
-                t += 1
                 time.sleep(60)
+            t += 1
 
     def test(self):
         import pandas as pd
@@ -157,9 +157,10 @@ class TradeUpdate:
 
 
 update = TradeUpdate()
-# update.run()
-update.test()
+update.run()
+# update.test()
 
 # ps -elf|grep coin
 # nohup /root/anaconda3/bin/python3.8 /root/workspace/notechats/notecoin/notecoin/huobi/dataset/update.py >>/root/workspace/tmp/notecoin-run-$(date +%Y-%m-%d).log 2>&1 &
 # 2509
+# sqlite3 -header -csv huobi.db "select * from trade_detail;" > trade_detail.csv
